@@ -114,7 +114,7 @@ def create_qlr(filename, fileqlr="", cmapname=None):
         ext = justext(filename).lower()
 
         metadata = GetMetaData(filename)
-        metadata = metadata["metadata"] if metadata and "metadata" in metadata else {}
+        metadata = metadata["metadata"] if metadata and "metadata" in metadata else {"metadata": {}}
 
 
         # Redefine sand, silt, clay cmap
@@ -123,7 +123,6 @@ def create_qlr(filename, fileqlr="", cmapname=None):
             if "type" not in metadata:
                 metadata["type"] = "viridis"
 
-            print(metadata)
             cmapname = cmapname if cmapname else metadata["type"]
 
             filetpl = pkg_resources.resource_filename(__name__, "data/raster.qlr")
@@ -173,9 +172,8 @@ def create_qlr(filename, fileqlr="", cmapname=None):
 
             # assert that "type" is a valid key
             if "type" not in metadata:
-                metadata["type"] = "Polygon"
+                metadata["type"] = cmapname
 
-            cmapname = cmapname if cmapname else metadata["type"]
             geomtype = GetGeomTypeName(filename)
             filetpl = pkg_resources.resource_filename(__name__, f"data/{geomtype}.qlr")
 
